@@ -48,11 +48,11 @@ gg <- ggplot(majors_alluvia,
 gg +
   geom_alluvium(aes(fill = as.factor(student)), width = 2/5, discern = TRUE) +
   geom_stratum(width = 2/5, discern = TRUE) +
-  geom_text(stat = "stratum", discern = TRUE, label.strata = TRUE)
+  geom_text(stat = "stratum", discern = TRUE, infer.label = TRUE)
 gg +
   geom_alluvium(aes(fill = as.factor(student)), width = 2/5, discern = FALSE) +
   geom_stratum(width = 2/5, discern = FALSE) +
-  geom_text(stat = "stratum", discern = FALSE, label.strata = TRUE)
+  geom_text(stat = "stratum", discern = FALSE, infer.label = TRUE)
 # warning when inappropriate
 ggplot(majors[majors$semester %in% paste0("CURR", c(1, 7, 13)), ],
        aes(x = semester, stratum = curriculum, alluvium = student,
